summaryrefslogtreecommitdiffstats
path: root/ui/events/event_constants.h
diff options
context:
space:
mode:
authordmazzoni@chromium.org <dmazzoni@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-05-29 19:01:44 +0000
committerdmazzoni@chromium.org <dmazzoni@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-05-29 19:01:44 +0000
commit34538533288487aa0002510f1abd78519831be7c (patch)
treeb3ef4b2d45e37664e226514dfb91f7b44483bc7b /ui/events/event_constants.h
parent41d70bd6049acc562fa0ff51bd3f7453d4969f07 (diff)
downloadchromium_src-34538533288487aa0002510f1abd78519831be7c.zip
chromium_src-34538533288487aa0002510f1abd78519831be7c.tar.gz
chromium_src-34538533288487aa0002510f1abd78519831be7c.tar.bz2
Make Views fire an accessible hover event on mouse enter.
This is used for touch accessibility on Chrome OS, see bug. Fires the AX event on mouse enter and passes this through to the accessibilityPrivate API for ChromeVox. BUG=377043 Review URL: https://codereview.chromium.org/297133002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@273529 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ui/events/event_constants.h')
-rw-r--r--ui/events/event_constants.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/ui/events/event_constants.h b/ui/events/event_constants.h
index a7ff8b1..4081e20 100644
--- a/ui/events/event_constants.h
+++ b/ui/events/event_constants.h
@@ -104,11 +104,13 @@ enum KeyEventFlags {
// Flags specific to mouse events
enum MouseEventFlags {
- EF_IS_DOUBLE_CLICK = 1 << 16,
- EF_IS_TRIPLE_CLICK = 1 << 17,
- EF_IS_NON_CLIENT = 1 << 18,
- EF_FROM_TOUCH = 1 << 19, // Indicates this mouse event is generated
- // from an unconsumed touch/gesture event.
+ EF_IS_DOUBLE_CLICK = 1 << 16,
+ EF_IS_TRIPLE_CLICK = 1 << 17,
+ EF_IS_NON_CLIENT = 1 << 18,
+ EF_FROM_TOUCH = 1 << 19, // Indicates this mouse event is generated
+ // from an unconsumed touch/gesture event.
+ EF_TOUCH_ACCESSIBILITY = 1 << 20, // Indicates this event was generated from
+ // touch accessibility mode.
};
// Result of dispatching an event.